function R=compute_correlation(v,H)

% where H is the template waveform 
% and v is the continuous signal
% we require that both signals are filtered similarly

% Get fourier transform of the continuous signal
[e,nv] = size(v);
if(nv ==1); v = v'; nv = e; end % Make sure we have the good shape
f_v = fft(v);


% Transform template signal
[nh1,nh2] = size(H); % Get size 
if(nh2 ==1); H = H'; nh2 = nh1; end % Make sure we have the good shape

H = H - mean(H); % remove mean
H = H.*tukeywin(nh2,0.1)'; % Tapering
H = H./std(H); % Normalize by standard deviation

npad = nv - nh2;
H = padarray(H,[0 npad],0,'post');
f_H = fft(H); % Get the Fourier transform of H (flipped and same size 
% as v.

% Compute the standard deviation of continuous signal
s_v= std_v(v,nv,nh2);

% Compute correlation
R = fliplr(real(ifft(f_H.*conj(f_v))));

% Get normalized values
R = R./s_v;

                
                
                
end



function s_v= std_v(v,nv,nw)
% This function computes the stabdard deviation on the continuous signal
% on windows of size nw
% Compute std for the first window
s1 = sum(v(1:nw));
s2 = v(1:nw)*v(1:nw)';
s_v(1) = sqrt( (s2-s1*s1/nw)/(nw-1));
% Initialize all values with this one
s_v(1:nv) = s_v(1);

% Increment
for i = 2:nv-nw+1
    s1 = s1 - v(i-1) + v(i+nw-1);
    s2 = s2 - v(i-1)*v(i-1) + v(i+nw-1)*v(i+nw-1);
    s_v(i ) =  sqrt( (s2-s1*s1/nw)/(nw-1));
end

% For the end of file
for i = nv-nw+2:nv
    s1 = s1 - v(i-1);
    s2 = s2 - v(i-1)*v(i-1);
    s_v(i ) =  sqrt( (s2-s1*s1/(nv-i))/(nv-i-1));
end

s_v = s_v * nw;

end