function [tp,sta,ntwk,channel]=read_xml(xmlfilename)

% Load the xml File architecture
F = parseXML(xmlfilename);

k1=xml_field(F,'eventParameters'); H = F.Children(k1);
k2=xml_field(H,'event'); H = H.Children(k2);
k3=xml_field(H,'pick');
% Several picks are possible
for ik = 1:length(k3)
    H_test = H.Children(k3(ik));
    % Test if we have the P wave 
    k=xml_field(H_test,'phaseHint'); 
    % If this is the P-wave read the informations
    if(strcmp(H_test.Children(k).Children(1).Data,'P'))
        k=xml_field(H_test,'waveformID'); A = H_test.Children(k);
        [sta,ntwk,channel] = read_xml_attributes(A);
        k=xml_field(H_test,'time');  G=H_test.Children(k);
        k=xml_field(G,'value'); G = G.Children(k);
        tp = datenum(G.Children(1).Data,'yyyy-mm-ddTHH:MM:SS.FFF');

    end

end



end

% Read waveform attributes
function [sta,ntwk,channel] = read_xml_attributes(A)
na = length(A.Attributes);
for ia = 1:na
    if(strcmp(A.Attributes(ia).Name,'channelCode'))
        channel = A.Attributes(ia).Value;
    end
    if(strcmp(A.Attributes(ia).Name,'networkCode'))
        ntwk = A.Attributes(ia).Value;
    end
    if(strcmp(A.Attributes(ia).Name,'stationCode'))
        sta = A.Attributes(ia).Value;
    end
end

end

% Get the current xml field with the name keystring
function [ikey]=xml_field(F,keystring)

nchilds = length(F.Children);
ikey = [];
for i = 1:nchilds
    if(strcmp(F.Children(i).Name,keystring))
        ikey = [ikey i];
    end
end
nmatch = length(ikey);
if(nmatch == 0) 
     error('No field %s', keystring)
end

end

function theStruct = parseXML(filename)
% PARSEXML Convert XML file to a MATLAB structure.
% THis functions is from MATLAB xmlread doc
try
   tree = xmlread(filename);
catch
   error('Failed to read XML file %s.',filename);
end

% Recurse over child nodes. This could run into problems 
% with very deeply nested trees.
try
   theStruct = parseChildNodes(tree);
catch
   error('Unable to parse XML file %s.',filename);
end

end

% ----- Local function PARSECHILDNODES -----
function children = parseChildNodes(theNode)
% Recurse over node children.
children = [];
if theNode.hasChildNodes
   childNodes = theNode.getChildNodes;
   numChildNodes = childNodes.getLength;
   allocCell = cell(1, numChildNodes);

   children = struct(             ...
      'Name', allocCell, 'Attributes', allocCell,    ...
      'Data', allocCell, 'Children', allocCell);

    for count = 1:numChildNodes
        theChild = childNodes.item(count-1);
        children(count) = makeStructFromNode(theChild);
    end
end

end

% ----- Local function MAKESTRUCTFROMNODE -----
function nodeStruct = makeStructFromNode(theNode)
% Create structure of node info.

nodeStruct = struct(                        ...
   'Name', char(theNode.getNodeName),       ...
   'Attributes', parseAttributes(theNode),  ...
   'Data', '',                              ...
   'Children', parseChildNodes(theNode));

if any(strcmp(methods(theNode), 'getData'))
   nodeStruct.Data = char(theNode.getData); 
else
   nodeStruct.Data = '';
end

end

% ----- Local function PARSEATTRIBUTES -----
function attributes = parseAttributes(theNode)
% Create attributes structure.

attributes = [];
if theNode.hasAttributes
   theAttributes = theNode.getAttributes;
   numAttributes = theAttributes.getLength;
   allocCell = cell(1, numAttributes);
   attributes = struct('Name', allocCell, 'Value', ...
                       allocCell);

   for count = 1:numAttributes
      attrib = theAttributes.item(count-1);
      attributes(count).Name = char(attrib.getName);
      attributes(count).Value = char(attrib.getValue);
   end
end

end